@@ -24,4 +24,7 @@
 #' @importFrom pipeR %>>%
 #' @importFrom utils globalVariables
 #' @importFrom RcppParallel RcppParallelLibs
-utils::globalVariables(c(".", "%>>%"))
+# @aliases milr-package milr
+# @keywords internal
+"_PACKAGE"
+utils::globalVariables(c(".", "%>>%"))
\ No newline at end of file
